compute_extended_ratios: Compute extended set of biomarker ratios
Description
Computes 76 additional ratios not provided by the Nightingale platform. These
include lipid fractions in HDL, LDL, VLDL, and total serum, as well as
cholesterol fractions, and omega to polyunsaturated fatty acid ratios. See
nmr_info for details.
Usage
compute_extended_ratios(x)
Value
a data.frame with the additional computed biomarker ratios.
Arguments
x
data.frame containing NMR metabolomics data from UK Biobank.
May either be raw field data output by
ukbconv
or data with column names corresponding to biomarkers listed in nmr_info.
Details
If your UK Biobank project only has access to a subset of biomarkers, then
this function will only return the subset of ratios that can be computed from
the biomarker data provided.
All biomarkers in the input data are also returned alongside the ratios computed
by this function.
See Also
nmr_info for list of computed biomarker ratios,
compute_extended_ratio_qc_flags() for obtaining an
aggregate of the biomarker QC flags from the biomarkers underlying each
computed ratio, and extract_biomarkers() for details on how
raw data from
ukbconv
is processed.