compute_lipoprotein_fatty_acids_flags: Aggregate QC Flags for the fatty acids computed in each...

View source: R/compute_qc_flags_user.R

compute_lipoprotein_fatty_acids_flagsR Documentation

Aggregate QC Flags for the fatty acids computed in each lipoprotein class and subclass

Description

For the 17 biomarkers computed by compute_lipoprotein_fatty_acids(), aggregates the biomarker QC flags from the underlying esterified cholesterol, phospholipids, and triglyceride components, which can be useful for determining the reason underlying missing values in the computed lipoprotein fatty acid biomarkers.

Usage

compute_lipoprotein_fatty_acids_flags(x)

Arguments

x

data.frame containing NMR metabolomics data from UK Biobank. May either be raw field data output by the Table Exporter tool on the UK Biobank Research Analysis Platform or data with column names corresponding to biomarkers listed in nmr_info.

Details

If your UK Biobank project only has access to a subset of biomarkers, then this function will only return the subset of ratios that can be computed from the biomarker data provided.

Biomarker QC Flags in the input data are also returned alongside those aggregated by this function for the computed biomarker ratios.

Value

a data.frame with QC flags aggregated for the computed lipoprotein fatty acids biomarkers.

See Also

nmr_info for list of computed lipoprotein fatty acid biomarkers, compute_lipoprotein_fatty_acids_flags() for obtaining an aggregate of the biomarker QC flags from the biomarkers underlying each computed lipoprotein fatty acid, and extract_biomarkers() for details on how raw field data extracted by the Table Exporter tool is processed.

Examples

ukb_data <- ukbnmr::test_data # Toy example dataset for testing package
biomarker_qc_flags <- compute_lipoprotein_fatty_acids_flags(ukb_data)


ukbnmr documentation built on July 7, 2026, 5:08 p.m.