recompute_derived_biomarker_qc_flags: Aggregate QC Flags when recomputing all composite and derived biomarkers
Description
For the 61 composite biomarkers, 81 Nightingale biomarker ratios, and 76
extended biomarker ratios computed by recompute_derived_biomarkers(),
aggregates the biomarker QC flags from the underlying biomarkers
(see nmr_info).
Usage
recompute_derived_biomarker_qc_flags(x)
Value
a data.frame with QC flags aggregated for all computed
biomarkers and ratios.
Arguments
x
data.frame containing NMR metabolomics data from UK Biobank.
May either be raw field data output by
ukbconv
or data with column names corresponding to biomarkers listed in nmr_info.
Details
If your UK Biobank project only has access to a subset of biomarkers, then
this function will only return the subset of ratios that can be computed from
the biomarker data provided.
Biomarker QC Flags in the input data are also returned alongside those
aggregated by this function for the computed biomarker ratios.
See Also
nmr_info for list of computed biomarker ratios and
extract_biomarkers() for details on how raw data from
ukbconv
is processed.