recompute_derived_biomarkers: Recompute composite biomarkers and ratios from the 107 non-derived biomarkers
Description
When adjusting biomarkers for unwanted biological covariates, it is desirable
to recompute composite biomarkers and ratios to ensure consistency in the
adjusted dataset. This function will compute all composite biomarkers and
ratios from their parts (see nmr_info for biomarker details).
Usage
recompute_derived_biomarkers(x)
Value
a data.frame with all composite biomarkers and ratios
(re)computed from the 107 non-derived biomarkers (see nmr_info
for details).
Arguments
x
data.frame containing NMR metabolomics data from UK Biobank.
May either be raw field data output by
ukbconv
or data with column names corresponding to biomarkers listed in nmr_info.
Details
If your UK Biobank project only has access to a subset of biomarkers, then
this function will only return the subset of ratios that can be computed from
the biomarker data provided.
All biomarkers in the input data are also returned alongside those computed
by this function.
See Also
nmr_info for list of computed biomarker ratios,
recompute_derived_biomarker_qc_flags() for obtaining an
aggregate of the biomarker QC flags from the biomarkers underlying each
computed biomarker, and extract_biomarkers() for details on
how the raw field data extracted by the Table Exporter tool is processed.