Contains details on the sample processing and quality control information for the NMR biomarker data in UK Biobank.
sample_qc_infoA data table with 18 rows and 3 columns:
Column name assigned to the sample information field
Brief description of the field contents. Further details on the Nightingale sample QC columns can be found in the accompanying resource on the UK Biobank showcase.
Field ID in UK Biobank, see https://biobank.ndph.ox.ac.uk/showcase/label.cgi?id=222.
Rows missing UKB.Field.ID entries correspond to additional sample
processing information derived from these fields and returned by remove_technical_variation.