View source: R/compute_qc_flags_user.R
| compute_lipoprotein_fatty_acids_flags | R Documentation |
For the 17 biomarkers computed by compute_lipoprotein_fatty_acids(),
aggregates the biomarker QC flags from the underlying esterified cholesterol,
phospholipids, and triglyceride components, which can be useful for
determining the reason underlying missing values in the computed lipoprotein
fatty acid biomarkers.
compute_lipoprotein_fatty_acids_flags(x)
x |
|
If your UK Biobank project only has access to a subset of biomarkers, then this function will only return the subset of ratios that can be computed from the biomarker data provided.
Biomarker QC Flags in the input data are also returned alongside those aggregated by this function for the computed biomarker ratios.
a data.frame with QC flags aggregated for the computed
lipoprotein fatty acids biomarkers.
nmr_info for list of computed lipoprotein fatty acid
biomarkers, compute_lipoprotein_fatty_acids_flags() for
obtaining an aggregate of the biomarker QC flags from the biomarkers
underlying each computed lipoprotein fatty acid, and
extract_biomarkers() for details on how raw field data
extracted by the Table Exporter tool is processed.
ukb_data <- ukbnmr::test_data # Toy example dataset for testing package
biomarker_qc_flags <- compute_lipoprotein_fatty_acids_flags(ukb_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.