| nmr_info | R Documentation |
Contains details on the Nightingale biomarkers available in UK Biobank and computed by this package.
If you use the estimated fatty acids in lipoprotein measurements please cite: Belkadi A. et al. Size-resolved lipoprotein fatty acid content as a novel nuclear magnetic resonance-derived trait specifically associates with genetic variants that control fatty acid metabolism. J. Proteome Res. (2026) doi: 10.1021/acs.jproteome.6c00107
nmr_info
A data table with 344 rows and 8 columns:
Short column name assigned to the biomarker
Biomarker description, matching the description field provided by UK Biobank and Nightingale Health
Units of measurement for the biomarker ("mmol/L", "g/L", "nm", "degree", "ratio", or "%")
Biomarker type ("Non-derived", "Composite", "Ratio", "Percentage", or "Estimate")
Biomarker group as provided by Nightingale Health
Biomarker sub-group as provided by Nightingale Health
Logical. Indicates biomarker is quantified by the Nightingale Health platform
Field ID in UK Biobank, see https://biobank.ndph.ox.ac.uk/showcase/label.cgi?id=220
Field ID in UK Biobank for the biomarker QC Flags, see https://biobank.ndph.ox.ac.uk/showcase/label.cgi?id=220
For composite biomarkers and ratios, details formula through which the biomarker can be derived from the 107 non-derived biomarkers
Simplified form of the full formula most clearly expressing how each composite biomarker and ratio can be rederived from other biomarkers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.